<?php

/**
 * Menu callback for administration form
 */
function commerce_abandoned_carts_admin_form() {  
  $form['text'] = array(
    '#type' => 'fieldset',
    '#title' => t('Commerce Abandoned Carts Settings'),
  );
  $form['text']['commerce_abandoned_carts_timeout'] = array(
    '#type'  => 'textfield',
    '#title' => t('Send Timeout'),
    '#default_value' => variable_get('commerce_abandoned_carts_timeout', 1440),
    '#description' => 'How many minutes to wait before sending the abandoned cart message in <strong>minutes</strong>. Note, there are 1440 minutes in one day?',
  );
    
  $form['text']['commerce_abandoned_carts_history_limit'] = array(
    '#type'  => 'textfield',
    '#title' => t('History Limit'),
    '#default_value' => variable_get('commerce_abandoned_carts_history_limit', 21600),
    '#description' => 'What is the limit (in minutes) to how far back to search for abandoned carts. Default is 15 days. ',
  );
  
  $statuses =commerce_order_statuses();
  $options = array();
  foreach ($statuses as $key => $status){
    $options[$key] = $status['title'];
  }
  
  $form['text']['commerce_abandoned_carts_abandoned_statuses'] = array(
    '#type'  => 'checkboxes',
    '#title' => t('Abandoned Statuses'),
    '#options' => $options,
    '#required' => TRUE,    
    '#default_value' => variable_get('commerce_abandoned_carts_abandoned_statuses', array('cart')),
    '#description' => 'Select all cart/order statuses that will be considered abandoned. Only carts/orders with the selected statuses will be processes for sending messages to.',
  );
  
  $options = array(
    5 => '5',
    10 => '10',
    25 => '25',
    50 => '50',
    75 => '75',
    100 => '100',    
  );
  
  $form['text']['commerce_abandoned_carts_batch_limit'] = array(
    '#type'  => 'select',
    '#options' => $options,
    '#title' => t('Batch Limit'),
    '#default_value' => variable_get('commerce_abandoned_carts_batch_limit', 10),
    '#description' => 'What is the maximum emails to send per cron run? Note, larger batches may cause performance issues.',
  );    
  
  $form['text']['commerce_abandoned_carts_from_email'] = array(
    '#type'  => 'textfield',
    '#title' => t('From Email Address'),
    '#default_value' => variable_get('commerce_abandoned_carts_from_email', ''),
    '#description' => 'Enter the email address to send the emails from. Leave blank to use site-wide email address.',
    '#size' => 40,
    '#maxlength' => 40,
    '#element_validate' => array('commerce_abandoned_carts_email_element_validate'),
  );   
  
  $form['text']['commerce_abandoned_carts_from_name'] = array(
  
    '#type'  => 'textfield',
    '#title' => t('From Email Name'),
    '#default_value' => variable_get('commerce_abandoned_carts_from_name', ''),
    '#description' => 'Enter the name to send the emails from. Leave blank to use site name.',
  );

  $form['text']['commerce_abandoned_carts_subject'] = array(
    '#type'  => 'textfield',
    '#title' => t('Subject Line'),
    '#default_value' => t(variable_get('commerce_abandoned_carts_subject', 'Your order is incomplete.')),
    '#description' => 'Enter the name to send the emails from. ',
  );
  
  $form['text']['commerce_abandoned_carts_customer_service_phone_number'] = array(
    '#type'  => 'textfield',
    '#title' => t('Customer Service Phone Number'),
    '#default_value' => variable_get('commerce_abandoned_carts_customer_service_phone_number', ''),
    '#description' => 'Enter a phone number to be displayed in the email template for customers who may have had trouble checking out. Leave empty to obmit from email.',
  );
  
  $form['text']['commerce_abandoned_carts_bcc_active'] = array(
    '#type' => 'checkbox',
    '#title' => t('Send BCC?'),
    '#default_value' => variable_get('commerce_abandoned_carts_bcc_active', 0),
    '#description' => t('Would you like to send a Blind Carbon Copy of all Abandoned Cart messages to an admin account for monintoring?'),
  );
  
  $form['text']['commerce_abandoned_carts_bcc_email'] = array(
    '#type' => 'textfield',
    '#title' => t('BCC Email Address'),
    '#required' => TRUE,
    '#default_value' => variable_get('commerce_abandoned_carts_bcc_email', variable_get('site_mail')),
    '#description' => "Enter the email address to send the test emails to.",
    '#size' => 40,
    '#maxlength' => 40,
    '#element_validate' => array('commerce_abandoned_carts_email_element_validate'),
    '#states' => array(
      'visible' => array(
        ':input[name="commerce_abandoned_carts_bcc_active"]' => array('checked' => TRUE),
        ),
      ),
  );
  
  $form['other'] = array(
    '#type' => 'fieldset',
    '#title' => t('Test Mode'),
  );

  $form['other']['commerce_abandoned_carts_testmode_active'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable Test Mode'),
    '#default_value' => variable_get('commerce_abandoned_carts_testmode_active', 1),
    '#description' => t('When test mode is active all abandoned carts messages will be sent to the test email address instead of cart owner for testing purposes. When in test module the status of the message is not updated so the same messages will be sent on each cron run.'),
  );

  $form['other']['commerce_abandoned_carts_testmode_email'] = array(
    '#type' => 'textfield',
    '#title' => t('Test Mode Email'),
    '#required' => TRUE,
    '#default_value' => variable_get('commerce_abandoned_carts_testmode_email', variable_get('site_mail')),
    '#description' => "Enter the email address to send the test emails to.",
    '#size' => 40,
    '#maxlength' => 40,
    '#element_validate' => array('commerce_abandoned_carts_email_element_validate'),
    '#states' => array(
      'visible' => array(
        ':input[name="commerce_abandoned_carts_testmode_active"]' => array('checked' => TRUE),
        ),
      ),
  ); 
    
  return system_settings_form($form);
}

/*
 * Validation function for administration form
 */
function commerce_abandoned_carts_admin_form_validate($form, &$form_state) {
  $values = $form_state['values'];
  $timeout = $values['commerce_abandoned_carts_timeout'];   
  $history_limit = $values['commerce_abandoned_carts_history_limit'];
  
  if (!is_numeric($timeout)){
    form_set_error('commerce_abandoned_carts_timeout', 'Timeout value must be a whole number.');
  }
  if (!is_numeric($history_limit)){
    form_set_error('commerce_abandoned_carts_history_limit', 'History limit value must be a whole number.');
  }
  if ($history_limit <= $timeout){
    form_set_error('commerce_abandoned_carts_history_limit', 'History limit value must greater than the timeout value.');
  }
}
  
/*
   * Element validation for email address field
*/
function commerce_abandoned_carts_email_element_validate($element, &$form_state, $form) {
   if (empty($element['#value'])) return;
   if (!valid_email_address($element['#value'])) {
     form_error($element, t('Please enter a valid email address.'));
   }
}  